<?php
/**
 * Plugin Name: myglobalHOST Lazy Load Rows and Columns
 * Plugin URI:  https://www.myglobalhost.in/
 * Description: Lazy loads rows and columns after the initial two rows and columns to improve page load performance.
 * Version:     1.0.0
 * Author:      myglobalHOST
 * Author URI:  https://www.myglobalhost.net/
 * License:     GPL2
 */

function lazy_load_rows_and_columns() {
    ?>
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            const observer = new IntersectionObserver((entries) => {
                entries.forEach((entry) => {
                    if (entry.isIntersecting) {
                        entry.target.classList.remove('lazy-row', 'lazy-column');
                        observer.unobserve(entry.target);
                    }
                });
            });

            const rows = document.querySelectorAll('.row'); 
            const columns = document.querySelectorAll('.column'); 

            rows.forEach((row, index) => {
                if (index >= 2) { // Lazy load rows after the first 2
                    row.classList.add('lazy-row');
                    observer.observe(row);
                }
            });

            columns.forEach((column, index) => {
                if (index >= 2) { // Lazy load columns after the first 2
                    column.classList.add('lazy-column');
                    observer.observe(column);
                }
            });
        });
    </script>
    <style>
        .lazy-row, .lazy-column {
            opacity: 0; 
            transition: opacity 0.3s ease-in; 
        }
    </style>
    <?php
}
add_action('wp_head', 'lazy_load_rows_and_columns');
